-- version and date
local revision = tonumber(("$Revision: 46515 $"):match("%d+"))
if not NSD_REVISION or revision > NSD_REVISION then
    NSD_REVISION = revision
    NSD_DATE = ("$Date: 2007-08-14 07:01:24 -0400 (Tue, 14 Aug 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")
end

-- localisations
local L = AceLibrary("AceLocale-2.2"):new("ShakedownSCT")
L:RegisterTranslations("enUS", function() return {
    ["Scrolling Combat Text"] = true,
} end)

-- constants
local COLOUR = {r=1, g=1, b=1}
local DRAG_WIDTH = 80
local DRAG_HEIGHT = 20

-- create the class
local AceOO = AceLibrary("AceOO-2.0")
Addon = AceOO.Class(ShakedownAddonBase, "AceEvent-2.0")

-- members
Addon.prototype.dragFrameSCT1 = nil
Addon.prototype.dragFrameSCT2 = nil
Addon.prototype.dragFrameSCT3 = nil
Addon.prototype.deltaX = 0
Addon.prototype.deltaY = 0

-- constructor
function Addon.prototype:init()
    Addon.super.prototype.init(self, "sct_options", L["Scrolling Combat Text"])
end

-- extra actions required after the LOD addon has been loaded
function Addon.prototype:Load()
    self:Debug("Addon:Load")

    if not Addon.super.prototype.Load(self) then return end
    
    self:Debug(" SCT loaded OK; checking for SCTD")

    -- hook the test functions for SCTD as well, if it has been installed
    if SCTD then
        --Hook SCT ShowExample
        if (not SCTD:IsHooked(SCT, "ShowExample")) then
            SCTD:Hook(SCT, "ShowExample");
        end
        --Hook SCT ShowTest
        if (not SCTD:IsHooked(SCT, "ShowTest")) then
            SCTD:Hook(SCT, "ShowTest");
        end
    end
    
    -- successful load
    return true
    
end

function Addon.prototype:Activate()

    if not Addon.super.prototype.Activate(self) then return end
    
    -- create the dragframes
    if not self.dragFrameSCT1 then
        self.dragFrameSCT1 = self:CreateDragFrame("dragFrameSCT1")
    end
    if not self.dragFrameSCT2 then
        self.dragFrameSCT2 = self:CreateDragFrame("dragFrameSCT2")
    end
    if not self.dragFrameSCT3 then
        self.dragFrameSCT3 = self:CreateDragFrame("dragFrameSCT3")
    end
    self:ShowDragFrame(self.dragFrameSCT1, SCT.db.profile.FRAMESDATA[1].XOFFSET, SCT.db.profile.FRAMESDATA[1].YOFFSET)
    self:ShowDragFrame(self.dragFrameSCT2, SCT.db.profile.FRAMESDATA[2].XOFFSET, SCT.db.profile.FRAMESDATA[2].YOFFSET)
    self:ShowDragFrame(self.dragFrameSCT3, SCT.db.profile.FRAMESDATA[10].MSGXOFFSET, SCT.db.profile.FRAMESDATA[10].MSGYOFFSET - 30) -- y-offset of 30 copied from SCT:ShowExample
    
    -- calculate the co-ord delta between that which we get from GetPoint and the centre aligned co-ords that SCT works with
    self.dragFrameSCT1:StartMoving()
    self.dragFrameSCT1:StopMovingOrSizing()
    local _, _, _, x, y = self.dragFrameSCT1:GetPoint()
    self.deltaX = SCT.db.profile.FRAMESDATA[1].XOFFSET - x
    self.deltaY = SCT.db.profile.FRAMESDATA[1].YOFFSET - y
    
    -- close the sct options menu
    if ( ColorPickerFrame:IsVisible() ) then
        ColorPickerFrame:Hide();
    end
    SCT:AniInit();
    SCT:HideMenu();
    
    -- display something now
    self:Display()
    
    -- schedule a display every second
    self:ScheduleRepeatingEvent("SCTShakedownDisplay", self.Display, 1, self)
    
end

function Addon.prototype:Deactivate()

    Addon.super.prototype.Deactivate(self)
    
    -- hide the dragframes
    self.dragFrameSCT1:Hide()
    self.dragFrameSCT2:Hide()
    self.dragFrameSCT3:Hide()

    -- stop display scheduling
    self:CancelScheduledEvent("SCTShakedownDisplay")

end

function Addon.prototype:Display()

   -- display some crits
    SCT:DisplayText(SCT.LOCALS.EXAMPLE, COLOUR, true, "damage", SCT.FRAME1)
    SCT:DisplayText(SCT.LOCALS.EXAMPLE2, COLOUR, true, "damage", SCT.FRAME2)
    if SCTD then
        SCT:DisplayText(SCTD.LOCALS.EXAMPLE, COLOUR, true, "damage", SCT.FRAME3)
    end

    -- display regular
    SCT:ShowTest()
    
end

function Addon.prototype:DragStart(this)

    this.isDragging = true
	this:StartMoving()
end

function Addon.prototype:DragStop(this)

    this:StopMovingOrSizing()
    this.isDragging = false
    
    local frameName = this:GetName()
    local _, _, _, x, y = this:GetPoint()
    if frameName == "dragFrameSCT1" then
        SCT.db.profile.FRAMESDATA[1].XOFFSET = x + self.deltaX
        SCT.db.profile.FRAMESDATA[1].YOFFSET = y + self.deltaY
    elseif frameName == "dragFrameSCT2" then
        SCT.db.profile.FRAMESDATA[2].XOFFSET = x + self.deltaX
        SCT.db.profile.FRAMESDATA[2].YOFFSET = y + self.deltaY
    elseif frameName == "dragFrameSCT3" then
        SCT.db.profile.FRAMESDATA[10].MSGXOFFSET = x + self.deltaX
        SCT.db.profile.FRAMESDATA[10].MSGYOFFSET = y + self.deltaY + 30 -- y-offset of 30 copied from SCT:ShowExample
    end
    SCT:ShowExample()
    
end

function Addon.prototype:CreateDragFrame(name)

    local frame = CreateFrame("Frame", name, UIParent)
    
    frame:SetBackdrop({ bgFile = self.backdropMayDrag, })
    frame:SetWidth(DRAG_WIDTH)
    frame:SetHeight(DRAG_HEIGHT)
    
    frame:EnableMouse(true)
    frame:SetMovable(true)
	frame:SetScript("OnDragStart", function(this) self:DragStart(this) end)
	frame:SetScript("OnDragStop", function(this) self:DragStop(this) end)
	frame:RegisterForDrag("LeftButton")
    
    return frame

end

function Addon.prototype:ShowDragFrame(frame, x, y)
    
    frame:ClearAllPoints()
    frame:SetPoint("CENTER", UIParent, "CENTER", x, y)
    frame:Show()
    
end

-- create the instance of this class
local thisAddon = Addon:new()